#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dhall
version:              1.42.3
visibility:           public
id:                   dhall-1.42.3-E9qlTm4p03qymOoVVWmFP
key:                  dhall-1.42.3-E9qlTm4p03qymOoVVWmFP
license:              BSD-3-Clause
copyright:            2017 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             A configuration language guaranteed to terminate
description:
    Dhall is an explicitly typed configuration language that is not Turing
    complete.  Despite being Turing incomplete, Dhall is a real programming
    language with a type-checker and evaluator.

    Use this library to parse, type-check, evaluate, and pretty-print the Dhall
    configuration language.  This package also includes an executable which
    type-checks a Dhall file and reduces the file to a fully evaluated normal
    form.

    Read "Dhall.Tutorial" to learn how to use this library

category:             Compiler
abi:                  5e1838c42b4a35e47c6fef00c3f6586d
exposed:              True
exposed-modules:
    Dhall Dhall.Binary Dhall.Context Dhall.Core Dhall.Crypto
    Dhall.Deriving Dhall.Diff Dhall.DirectoryTree Dhall.Format
    Dhall.Freeze Dhall.Import Dhall.Lint Dhall.Main Dhall.Map
    Dhall.Marshal.Decode Dhall.Marshal.Encode Dhall.Optics
    Dhall.Package Dhall.Parser Dhall.Parser.Expression
    Dhall.Parser.Token Dhall.Pretty Dhall.Repl Dhall.Schemas Dhall.Set
    Dhall.Src Dhall.Substitution Dhall.TH Dhall.Tags Dhall.Tutorial
    Dhall.TypeCheck Dhall.Util Dhall.Version

hidden-modules:
    Dhall.DirectoryTree.Types Dhall.Eval Dhall.Import.Types
    Dhall.Import.Headers Dhall.Marshal.Internal Dhall.Normalize
    Dhall.Parser.Combinators Dhall.Pretty.Internal Dhall.Syntax
    Dhall.Syntax.Binding Dhall.Syntax.Chunks Dhall.Syntax.Const
    Dhall.Syntax.Expr Dhall.Syntax.FunctionBinding Dhall.Syntax.Import
    Dhall.Syntax.Instances.Applicative Dhall.Syntax.Instances.Bifunctor
    Dhall.Syntax.Instances.Data Dhall.Syntax.Instances.Eq
    Dhall.Syntax.Instances.Foldable Dhall.Syntax.Instances.Functor
    Dhall.Syntax.Instances.Lift Dhall.Syntax.Instances.Monad
    Dhall.Syntax.Instances.NFData Dhall.Syntax.Instances.Ord
    Dhall.Syntax.Instances.Pretty Dhall.Syntax.Instances.Show
    Dhall.Syntax.Instances.Traversable Dhall.Syntax.MultiLet
    Dhall.Syntax.Operations Dhall.Syntax.RecordField Dhall.Syntax.Types
    Dhall.Syntax.Var Dhall.URL Paths_dhall Dhall.Import.HTTP
    Dhall.Import.Manager

import-dirs:          /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/dhall-1.42.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall
hs-libraries:         HSdhall-1.42.3-E9qlTm4p03qymOoVVWmFP
depends:
    Diff-0.5-KXelOT1A7XYBE1m5Mxpw7N
    aeson-2.2.1.0-IFj7FSeQ5R79PZnh3ksXrW
    aeson-pretty-0.8.10-Dq46Vb0SwSV2AiUtN6wUKh
    ansi-terminal-1.1-CI3Z2kdMs2nHILfQB59SyQ
    atomic-write-0.2.1.1-JQdGt33rh52oTExra2hi9 base-4.18.2.1
    base16-bytestring-1.0.2.0-31yUxkNIVeJ6WQ1ftMFCcb
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-L8b71mleMbHJVaC8zF8N1a
    cborg-0.2.10.0-Ilu9AOC1piX8LxIXTU9axO
    cborg-json-0.2.6.0-GqqqJ0KQgq87t01nlRE18F containers-0.6.7
    contravariant-1.5.6-DrebhAx4XwC59wq9S42cYg
    cryptohash-sha256-0.11.102.1-HfN6tMtKFbzLVsS44oCtEu
    data-fix-0.3.4-JIIyGWODpkQ6Cv3DGkVuWr deepseq-1.4.8.1
    directory-1.3.8.5 dotgen-0.4.3-A2UTkkV6Fes7fbL6Rpf3sY
    either-5.0.3-L97RCqrWS38xl66yyS973 exceptions-0.10.7
    filepath-1.4.300.1 half-0.3.3-AxmjEcKCga15jrHLeSwtSM
    hashable-1.4.7.0-JuZCUcgZ6993MAquoa2cCW haskeline-0.8.2.1
    http-client-0.7.19-9meVfWioNG49hhaNpvORg0
    http-client-tls-0.3.6.4-9KaGRUfQlOcH11qQFZ8oLV
    http-types-0.12.4-4tdX51H3YCXI63KUlr8q5w
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    megaparsec-9.7.0-2gGX6HbUqVZ7B58w8DDw7p
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-mtl-0.2.1.0-Ewo8HmKpWhTASatFX3KZGS
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-1K7fB5RWUkvJzcj2EjtnE4
    optparse-applicative-0.18.1.0-3oCCN3996F8HtRiEC4P5yD
    parser-combinators-1.3.1-8aQ8dKOwDVmFxT1S1WvW6m
    parsers-0.12.12-8SQd30A0FjtFXEkvloMdas
    pretty-simple-4.1.4.0-1ROAKrBN4xO5WL4HZFyvkL
    prettyprinter-1.7.1-890hJtP71KxJCLiD1l5JnX
    prettyprinter-ansi-terminal-1.1.3-G3Jgi8iGiEwJ3EPlBOH51X
    repline-0.4.3.0-8K1qOV9c7aG2gqDtsaBJvy
    scientific-0.3.8.1-38VvnYA00bD5k7zFFQre1V
    serialise-0.2.6.1-DQCkgjCgCmp6v8FbW8OIIf template-haskell-2.20.0.0
    text-2.0.2 text-manipulate-0.3.1.0-5e2Ht06zL12P389WUjf7T
    text-short-0.1.6.1-8bwmd8TEwOv6agYrzrVBw0
    th-lift-instances-0.1.20-FVACtvKHKUXJEGN8xv22ay time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unix-compat-0.7.4.1-D5z0oaVDOHE7a26PpKdQ2K
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq
    vector-0.13.2.0-5hQDxYlIzjI43Z4IxwIpHc

haddock-interfaces:   /usr/share/doc/dhall/html/dhall.haddock
haddock-html:         /usr/share/doc/dhall/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

